==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/SkuCapacityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.SkuCapacityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description of the App Service plan scale options.
 * @property default Default number of workers for this App Service plan SKU.
 * @property elasticMaximum Maximum number of Elastic workers for this App Service plan SKU.
 * @property maximum Maximum number of workers for this App Service plan SKU.
 * @property minimum Minimum number of workers for this App Service plan SKU.
 * @property scaleType Available scale configurations for an App Service plan.
 */
public data class SkuCapacityArgs(
    public val default: Output<Int>? = null,
    public val elasticMaximum: Output<Int>? = null,
    public val maximum: Output<Int>? = null,
    public val minimum: Output<Int>? = null,
    public val scaleType: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.SkuCapacityArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.SkuCapacityArgs =
        com.pulumi.azurenative.web.inputs.SkuCapacityArgs.builder()
            .default_(default?.applyValue({ args0 -> args0 }))
            .elasticMaximum(elasticMaximum?.applyValue({ args0 -> args0 }))
            .maximum(maximum?.applyValue({ args0 -> args0 }))
            .minimum(minimum?.applyValue({ args0 -> args0 }))
            .scaleType(scaleType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuCapacityArgs].
 */
@PulumiTagMarker
public class SkuCapacityArgsBuilder internal constructor() {
    private var default: Output<Int>? = null

    private var elasticMaximum: Output<Int>? = null

    private var maximum: Output<Int>? = null

    private var minimum: Output<Int>? = null

    private var scaleType: Output<String>? = null

    /**
     * @param value Default number of workers for this App Service plan SKU.
     */
    @JvmName("ukmwrpdfwdetoxxq")
    public suspend fun default(`value`: Output<Int>) {
        this.default = value
    }

    /**
     * @param value Maximum number of Elastic workers for this App Service plan SKU.
     */
    @JvmName("acsonfhqcdfpgnno")
    public suspend fun elasticMaximum(`value`: Output<Int>) {
        this.elasticMaximum = value
    }

    /**
     * @param value Maximum number of workers for this App Service plan SKU.
     */
    @JvmName("yglauogwmndpesbj")
    public suspend fun maximum(`value`: Output<Int>) {
        this.maximum = value
    }

    /**
     * @param value Minimum number of workers for this App Service plan SKU.
     */
    @JvmName("tsixlpmhbtoivwle")
    public suspend fun minimum(`value`: Output<Int>) {
        this.minimum = value
    }

    /**
     * @param value Available scale configurations for an App Service plan.
     */
    @JvmName("odbknmdposqmnxqv")
    public suspend fun scaleType(`value`: Output<String>) {
        this.scaleType = value
    }

    /**
     * @param value Default number of workers for this App Service plan SKU.
     */
    @JvmName("safpjbitwghfnpam")
    public suspend fun default(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.default = mapped
    }

    /**
     * @param value Maximum number of Elastic workers for this App Service plan SKU.
     */
    @JvmName("iswhbqyjmjkpfsgo")
    public suspend fun elasticMaximum(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.elasticMaximum = mapped
    }

    /**
     * @param value Maximum number of workers for this App Service plan SKU.
     */
    @JvmName("xuljgyxhsdynqqhw")
    public suspend fun maximum(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maximum = mapped
    }

    /**
     * @param value Minimum number of workers for this App Service plan SKU.
     */
    @JvmName("desabmxhqyfpvalk")
    public suspend fun minimum(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minimum = mapped
    }

    /**
     * @param value Available scale configurations for an App Service plan.
     */
    @JvmName("pbiatoeditslfifw")
    public suspend fun scaleType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scaleType = mapped
    }

    internal fun build(): SkuCapacityArgs = SkuCapacityArgs(
        default = default,
        elasticMaximum = elasticMaximum,
        maximum = maximum,
        minimum = minimum,
        scaleType = scaleType,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/SkuCapacityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.SkuCapacityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Description of the App Service plan scale options.
 * @property default Default number of workers for this App Service plan SKU.
 * @property elasticMaximum Maximum number of Elastic workers for this App Service plan SKU.
 * @property maximum Maximum number of workers for this App Service plan SKU.
 * @property minimum Minimum number of workers for this App Service plan SKU.
 * @property scaleType Available scale configurations for an App Service plan.
 */
public data class SkuCapacityArgs(
    public val default: Output<Int>? = null,
    public val elasticMaximum: Output<Int>? = null,
    public val maximum: Output<Int>? = null,
    public val minimum: Output<Int>? = null,
    public val scaleType: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.SkuCapacityArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.SkuCapacityArgs =
        com.pulumi.azurenative.web.inputs.SkuCapacityArgs.builder()
            .default_(default?.applyValue({ args0 -> args0 }))
            .elasticMaximum(elasticMaximum?.applyValue({ args0 -> args0 }))
            .maximum(maximum?.applyValue({ args0 -> args0 }))
            .minimum(minimum?.applyValue({ args0 -> args0 }))
            .scaleType(scaleType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkuCapacityArgs].
 */
@PulumiTagMarker
public class SkuCapacityArgsBuilder internal constructor() {
    private var default: Output<Int>? = null

    private var elasticMaximum: Output<Int>? = null

    private var maximum: Output<Int>? = null

    private var minimum: Output<Int>? = null

    private var scaleType: Output<String>? = null

    /**
     * @param value Default number of workers for this App Service plan SKU.
     */
    @JvmName("qvikmnxogactpvgc")
    public suspend fun default(`value`: Output<Int>) {
        this.default = value
    }

    /**
     * @param value Maximum number of Elastic workers for this App Service plan SKU.
     */
    @JvmName("hxxivkkopjaquoah")
    public suspend fun elasticMaximum(`value`: Output<Int>) {
        this.elasticMaximum = value
    }

    /**
     * @param value Maximum number of workers for this App Service plan SKU.
     */
    @JvmName("gbdevgysslmkygkf")
    public suspend fun maximum(`value`: Output<Int>) {
        this.maximum = value
    }

    /**
     * @param value Minimum number of workers for this App Service plan SKU.
     */
    @JvmName("najtmmgugiasahdq")
    public suspend fun minimum(`value`: Output<Int>) {
        this.minimum = value
    }

    /**
     * @param value Available scale configurations for an App Service plan.
     */
    @JvmName("lctmqxesivrfncqt")
    public suspend fun scaleType(`value`: Output<String>) {
        this.scaleType = value
    }

    /**
     * @param value Default number of workers for this App Service plan SKU.
     */
    @JvmName("hvylebmwcnequsvx")
    public suspend fun default(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.default = mapped
    }

    /**
     * @param value Maximum number of Elastic workers for this App Service plan SKU.
     */
    @JvmName("djaxaqetlllaovsj")
    public suspend fun elasticMaximum(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.elasticMaximum = mapped
    }

    /**
     * @param value Maximum number of workers for this App Service plan SKU.
     */
    @JvmName("voxygwvhhmvtadqg")
    public suspend fun maximum(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maximum = mapped
    }

    /**
     * @param value Minimum number of workers for this App Service plan SKU.
     */
    @JvmName("gekvtolviiqyocxr")
    public suspend fun minimum(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minimum = mapped
    }

    /**
     * @param value Available scale configurations for an App Service plan.
     */
    @JvmName("mggvqfkoocrgpcji")
    public suspend fun scaleType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scaleType = mapped
    }

    internal fun build(): SkuCapacityArgs = SkuCapacityArgs(
        default = default,
        elasticMaximum = elasticMaximum,
        maximum = maximum,
        minimum = minimum,
        scaleType = scaleType,
    )
}
